LottieContent class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

LottieContent({String? url, String? asset, bool repeat = false, double width = 100, double height = 100, String? id})
const
LottieContent.fromJson(Map<String, dynamic> json)
factory

Properties

asset → String?
final
contentType → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
id → String?
finalinherited
repeat → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
final
width → double
final

Methods

createWidget() → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

type → const String