SurveyResult class

The aggregated result of a completed or closed survey. Contains all StepResults collected during the session plus timing and finish metadata.

Annotations
  • @immutable
  • @JsonSerializable.new(explicitToJson: true)
  • @CustomDateTimeConverter.new()

Constructors

SurveyResult({required String id, required DateTime startTime, required DateTime endTime, required FinishReason finishReason, required List<StepResult> results})
const
SurveyResult.fromJson(Map<String, dynamic> json)
factory

Properties

endTime DateTime
The time the survey ended.
final
finishReason FinishReason
How the survey was finished.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Identifier matching the SurveyDefinition.id of the survey that produced this result.
final
results List<StepResult>
The ordered list of step results collected during the survey.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
The time the survey was started.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override