TextAnswerFormat class

Answer format for free-text entry. The JSON type identifier is 'text'.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

TextAnswerFormat({int? maxLines, String hint = '', String? validationRegEx = r'^(?!s*$).+', String? question, String? answerType = TextAnswerFormat.type})
const
TextAnswerFormat.fromJson(Map<String, dynamic> json)
factory

Properties

answerType String?
JSON type discriminator used during deserialization.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hint String
final
maxLines int?
Maximum number of lines in the text field. Null means unlimited.
final
question String?
Optional question text associated with this answer format.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validationRegEx String?
Regular expression by which the text gets validated default: '^(?!\s*$).+' that checks if the entered text is empty to allow any type of an answer including an empty one; set it explicitly to null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this answer format to a JSON map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

type → const String