TimeAnswerFormat class

Answer format that presents a time picker. The JSON type identifier is 'time'.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

TimeAnswerFormat({TimeOfDay? defaultValue, String? question, String? answerType = TimeAnswerFormat.type})
const
TimeAnswerFormat.fromJson(Map<String, dynamic> json)
factory

Properties

answerType String?
JSON type discriminator used during deserialization.
finalinherited
defaultValue TimeOfDay?
The time pre-selected when the picker is first shown.
final
hashCode int
The hash code for this object.
no setterinherited
question String?
Optional question text associated with this answer format.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this answer format to a JSON map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

type → const String