SurveyKit class
The root widget for a survey experience. Provide a SurveyDefinition via task and receive results via onResult. Customize navigation with surveyController, appearance with surveyProgressbarConfiguration and appBar, and extend with answerViewBuilders, contentWidgetBuilders, or registries.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SurveyKit
Constructors
-
SurveyKit({Key? key, required SurveyDefinition task, required dynamic onResult(SurveyResult), SurveyController? surveyController, SurveyProgressConfiguration? surveyProgressbarConfiguration, PreferredSizeWidget? appBar, Map<
String, String> ? localizations, StepShell? stepShell, BoxDecoration? decoration, Color? backgroundColor, Map<Type, AnswerViewBuilder> ? answerViewBuilders, Map<Type, ContentWidgetBuilder> ? contentWidgetBuilders, List<SurveyKitPlugin> ? registries}) -
const
Properties
-
answerViewBuilders
→ Map<
Type, AnswerViewBuilder> ? -
Custom answer-view builder overrides, keyed by AnswerFormat type.
final
- appBar → PreferredSizeWidget?
-
The appbar that is shown at the top
final
- backgroundColor → Color?
-
Optional background color for the survey scaffold.
final
-
contentWidgetBuilders
→ Map<
Type, ContentWidgetBuilder> ? -
Custom content-widget builder overrides, keyed by Content type.
final
- decoration → BoxDecoration?
-
Decoration which is applied to the survey container
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
localizations
→ Map<
String, String> ? -
Localizations for the survey
final
- onResult → dynamic Function(SurveyResult)
-
Function which is called after the results are collected
final
-
registries
→ List<
SurveyKitPlugin> ? -
List of SurveyKitPlugins whose builders are merged into the registry.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepShell → StepShell?
-
Step shell
final
- surveyController → SurveyController?
-
SurveyController to override the navigation methods
onNextStep, onBackStep, onCloseSurvey
final
- surveyProgressbarConfiguration → SurveyProgressConfiguration?
-
final
- task → SurveyDefinition
-
SurveyDefinition for the configuration of the survey.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _SurveyKitState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited